<?php
/* constant strings
 * $Revision: 1.95.2.1 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XOONIPS_ADMIN", "XooNIps 設定" );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS', '既存ユーザをXooNIpsへ登録' );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS_NON_XOONIPS_USER', '非XooNIpsユーザ' );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS_XOONIPS_USER', 'XooNIpsユーザ' );
define( '_MD_XOONIPS_ADMIN_PICK_UP_USERS_ADD_TO_XOONIPS', '追加 -->' );
define( '_MD_XOONIPS_ADMIN_EDIT_DELETE_USER', 'ユーザ操作' );
define( '_MD_XOONIPS_ADMIN_EDIT_DELETE_USER_EXPLANATION', 'ユーザの編集・削除を行う場合は，最初に下からユーザを選び，次にユーザ操作を選択してください．' );
define( '_MD_XOONIPS_ADMIN_ADD_USER_EXPLANATION', '新しいユーザを作る場合は，以下のフォームに必要な情報を入力してください．' );

//module title for display
define( "_MD_XNPITEM", "アイテム管理" );

define( "_MD_XOONIPS_ITEM_LISTING_ITEM", "アイテム一覧" );
define( "_MD_XOONIPS_ITEM_ORDER_BY", "並び順 : " );
define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM_PER_PAGE", "No.Item per page" );
define( "_MD_XOONIPS_ITEM_SELECT_ITEM_TYPE_LABEL", "アイテムタイプ選択" );
define( "_MD_XOONIPS_ITEM_ADD_ITEM_BUTTON_LABEL", "アイテム追加" );
define( "_MD_XOONIPS_ITEM_EDIT_INDEX_BUTTON_LABEL", "インデックス編集" );
define( "_MD_XOONIPS_ITEM_SEARCH_RESULT", "検索結果" );
define( "_MD_XOONIPS_ITEM_SEARCH_KEYWORD", "検索キーワード" );
define( "_MD_XOONIPS_ITEM_SEARCH_ITEMTYPE", "検索対象" );
define( "_MI_XOONIPS_ITEM_SEARCH_TAB_ITEM", "アイテム" );
define( "_MI_XOONIPS_ITEM_SEARCH_TAB_METADATA", "メタデータ" );
define( "_MI_XOONIPS_ITEM_SEARCH_TAB_FILE", "ファイル" );
define( "_MI_XOONIPS_ITEM_NO_ITEM_LISTED", "ツリーを開いてさらに子インデックス内もブラウズしてみて下さい" );

define( "_MD_XOONIPS_ITEM_DETAIL_ITEM_TITLE", "詳細" );
define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_TITLE", "編集" );
define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_CONFIRM", "編集" );
define( "_MD_XOONIPS_ITEM_MODIFY_ITEM_CONFIRM_MESSAGE", "" );
define( "_MD_XOONIPS_ITEM_REGISTER_ITEM_TITLE", "登録" );
define( "_MD_XOONIPS_ITEM_REGISTER_ITEM_CONFIRM", "登録" );
define( "_MD_XOONIPS_ITEM_REGISTER_ITEM_CONFIRM_MESSAGE", "" );

define( "_MD_XOONIPS_ITEM_PRINT_FRIENDLY_BUTTON_LABEL", "印刷" );
define( "_MD_XOONIPS_ITEM_UPDATE_BUTTON_LABEL", "更新" );
define( "_MD_XOONIPS_ITEM_DELETE_BUTTON_LABEL", "削除" );
define( "_MD_XOONIPS_ITEM_REGISTER_BUTTON_LABEL", "登録" );
define( "_MD_XOONIPS_ITEM_MODIFY_BUTTON_LABEL", "編集" );
define( "_MD_XOONIPS_ITEM_NEXT_BUTTON_LABEL", "次へ" );
define( "_MD_XOONIPS_ITEM_BACK_BUTTON_LABEL", "戻る" );

define( "_MD_XOONIPS_ITEM_CERTIFY_ITEM_TITLE", "アイテム承認" );
define( "_MD_XOONIPS_ITEM_CERTIFY_BUTTON_LABEL", "Accept" );
define( "_MD_XOONIPS_ITEM_UNCERTIFY_BUTTON_LABEL", "Reject" );
define( "_MD_XOONIPS_ITEM_WITHDRAW_BUTTON_LABEL", "Withdraw" );

define( "_MD_XOONIPS_ITEM_ITEM_LABEL", "アイテム" );
define( "_MD_XOONIPS_ITEM_INDEX_LABEL", "インデックス" );

define( "_MD_XOONIPS_ITEM_SELECT_BUTTON_LABEL", "選択" );
define( "_MD_XOONIPS_ITEM_SELECT_NONE_LABEL", "なし" );

define( "_MD_XOONIPS_ITEM_README_LABEL", "Readme" );
define( "_MD_XOONIPS_ITEM_LICENSE_LABEL", "License" );
define( "_MD_XOONIPS_ITEM_RIGHTS_LABEL", "Rights" );
define( "_MD_XOONIPS_ITEM_PREVIEW_LABEL", "プレビュー" );
define( "_MD_XOONIPS_ITEM_CAPTION_LABEL", "プレビューのキャプション" );
define( "_MD_XOONIPS_ITEM_ATTACHMENT_LABEL", "添付ファイル" );
define( "_MD_XOONIPS_ITEM_TEXTFILE_LABEL", "テキストファイル" );
define( "_MD_XOONIPS_ITEM_FILE_HEAD_LABEL", "ファイル：" );
define( "_MD_XOONIPS_ITEM_CAPTION_HEAD_LABEL", "キャプション：" );
define( "_MD_XOONIPS_ITEM_ORIGINAL_FILE_NAME_LABEL", "元ファイル名" );
define( "_MD_XOONIPS_ITEM_MIME_TYPE_LABEL", "Mime-type" );
define( "_MD_XOONIPS_ITEM_TYPE_LABEL", "Type" );
define( "_MD_XOONIPS_ITEM_SIZE_LABEL", "Size" );
define( "_MD_XOONIPS_ITEM_LAST_UPDATED_LABEL", "Last updated" );
define( "_MD_XOONIPS_ITEM_DOWNLOAD_LABEL", "Download" );

define( "_MD_XOONIPS_ITEM_TEXT_FILE_EDIT_LABEL", "編集" );
define( "_MD_XOONIPS_ITEM_UPLOAD_LABEL", "更新" );
define( "_MD_XOONIPS_ITEM_OK_LABEL", "OK" );
define( "_MD_XOONIPS_ITEM_CANCEL_LABEL", "キャンセル" );

define( "_MD_XOONIPS_ITEM_FROM_LABEL", "From" );
define( "_MD_XOONIPS_ITEM_TO_LABEL", "To" );

define( "_MD_XOONIPS_ITEM_TITLE_REQUIRED", "'タイトル' を入力して下さい．" );
define( "_MD_XOONIPS_ITEM_UPLOAD_PREVIEW", "先にUploadボタンを押して、プレビューファイル '%s' をアップロードしてください．" );

define( "_MD_XOONIPS_ITEM_REQUIRED_MARK", "<font color=red>*</font>" );
define( "_MD_XOONIPS_ITEM_DOWNLOAD_CONFIRMATION", "このファイルのライセンス文に合意しますか？" );

define( "_MD_XOONIPS_ADD_TO_PUBLIC_EXPLANATION", "公開領域へ追加<br />" );
define( "_MD_XOONIPS_ADD_TO_PUBLIC_LABEL", "追加" );

//Basic Information field name
define( "_MD_XOONIPS_ITEM_TITLE_LABEL", "タイトル" );
define( "_MD_XOONIPS_ITEM_KEYWORDS_LABEL", "フリーキーワード" );
define( "_MD_XOONIPS_ITEM_DESCRIPTION_LABEL", "コメント" );
define( "_MD_XOONIPS_ITEM_DOI_LABEL", "ID" );
define( "_MD_XOONIPS_ITEM_ITEM_TYPE_LABEL", "アイテムタイプ" );
define( "_MD_XOONIPS_ITEM_CREATION_DATE_LABEL", "作成日" );
define( "_MD_XOONIPS_ITEM_LAST_UPDATE_DATE_LABEL", "最終更新日" );
define( "_MD_XOONIPS_ITEM_CHANGELOG_LABEL", "変更内容" );
define( "_MD_XOONIPS_ITEM_CHANGELOGS_LABEL", "更新履歴" );
define( "_MD_XOONIPS_ITEM_CONTRIBUTOR_LABEL", "登録者" );
define( "_MD_XOONIPS_ITEM_UID_LABEL", "登録者ID" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_DATE_LABEL", "日付" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_YEAR_LABEL", "年" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_MONTH_LABEL", "月" );
define( "_MD_XOONIPS_ITEM_PUBLICATION_MDAY_LABEL", "日" );

define( "_MD_XOONIPS_ITEM_SELECT_INDEX", "インデックスツリーからインデックスを選択して下さい．" );
define( "_MD_XOONIPS_ITEM_SELECT_PRIVATE_INDEX", "少なくとも 1つのプライベートインデックスをツリーから選択して下さい．" );
define( "_MD_XOONIPS_ITEM_NEED_TO_BE_CERTIFIED", "公開されるためにはモデレータもしくはグループ管理者の承認が必要です．この作業には数日要する場合があります．" );
define( "_MD_XOONIPS_ITEM_FORBIDDEN"    ,"このエリアへのアクセス権がありません．" );
define( "_MD_XOONIPS_ITEM_CANNOT_ACCESS_ITEM"    ,"このアイテムへのアクセス権がありません．" );
define( "_MD_XOONIPS_ITEM_DELETE_CONFIRMATION_MESSAGE", "本当に削除してよろしいですか?" );
define( "_MD_XOONIPS_ITEM_ACCEPT_CERTIFY_CONFIRMATION_MESSAGE", "本当にこのアイテム公開を承認してよろしいですか?" );
define( "_MD_XOONIPS_ITEM_CANCEL_CERTIFY_CONFIRMATION_MESSAGE", "本当にこのアイテム公開を却下してよろしいですか?" );
define( "_MD_XOONIPS_ITEM_WITHDRAW_CONFIRMATION_MESSAGE", "本当にこのアイテム公開を却下してよろしいですか?" );

define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_SUBJECT", "新規に登録されたアイテム" );
define( "_MD_XOONIPS_ITEM_NEW_REGISTRATION_ITEMS_MAIL_BODY", "" );

define( "_MD_XOONIPS_ITEM_DETAIL_URL", "詳細なURL" );
define( "_MD_XOONIPS_ITEM_ADVANCED_SEARCH_TITLE", "アイテム検索" );

define( "_MD_XOONIPS_ITEM_UPLOAD_FILE_TOO_LARGE", "アップロードするファイルが大きすぎます．");
define( "_MD_XOONIPS_ITEM_UPLOAD_FILE_FAILED", "ファイルをアップロードできません．" );
define( "_MD_XOONIPS_ITEM_THUMBNAIL_BAD_FILETYPE", "未対応のファイル形式です．サムネイルが作成できません．" );
define( "_MD_XOONIPS_ITEM_NO_CERTIFY_ITEMS", "新規登録アイテムはありません．" );
define( "_MD_XOONIPS_HEADER_CERTIFY_ITEMS", "以下のアイテムを承認して下さい．" );

define( "_MD_XOONIPS_ITEM_WARNING_ITEM_NUMBER_LIMIT", "これ以上アイテムを登録できません．サイト管理者に連絡して下さい．" );
define( "_MD_XOONIPS_ITEM_WARNING_INDEX_NUMBER_LIMIT", "これ以上インデックスを登録できません．サイト管理者に連絡して下さい．" );
define( "_MD_XOONIPS_ITEM_WARNING_ITEM_STORAGE_LIMIT", "ディスク領域が足りません．これ以上アイテムを登録できません．サイト管理者に連絡して下さい．" );
define( "_MD_XOONIPS_ITEM_WARNING_FIELD_TRIM", "文字数制限のため、赤字で示した部分は切り捨てられます" );

define( "_MD_XOONIPS_ITEM_NUM_OF_ITEM", "アイテム数" );
define( "_MD_XOONIPS_ITEM_STORAGE_OF_ITEM", "添付ファイル容量" );

define( "_MI_XOONIPS_ITEM_PANKUZU_ADVANCED_SEARCH", "詳細検索" );
define( "_MI_XOONIPS_ITEM_PANKUZU_REGISTER_ITEM", "新規アイテム登録" );
define( "_MD_XOONIPS_ITEM_SEARCH_BUTTON_LABEL", "検索" );

define( "_MI_XOONIPS_ITEM_PENDING_NOW", "(Pending)" );

define( "_MD_XOONIPS_ITEM_BAD_FILE", "不正なファイル" );
define( "_MD_XOONIPS_ITEM_BAD_FILE_TYPE", "不正なファイル形式" );
define( "_MD_XOONIPS_ITEM_CANNOT_CREATE_TMPFILE", "テンポラリファイルを作成できません．" );
define( "_MD_XOONIPS_ITEM_CANNOT_CREATE_ZIP", "ZIPファイルを作成できません．" );
define( "_MD_XOONIPS_ITEM_SEARCH_ERROR", "検索の問い合わせに失敗しました．" );
define( "_MD_XOONIPS_ITEM_SEARCH_SYNTAX_ERROR", "検索式の文法に誤りがあります．" );
define( "_MD_XOONIPS_ITEM_DELETE_NONPUBLIC_ITEM", "%d個の非公開アイテムがあるので，バインダーを公開できません．これらの非公開アイテムを削除してバインダーを公開しますか？" );

define( "_MD_XOONIPS_ITEM_EMPTY_BINDER_SUBJECT", "バインダー内のアイテムが0個になります" );
define( "_MD_XOONIPS_ITEM_EMPTY_BINDER_BODY", "バインダー '%s' 内のアイテムが0個になります.\n\nurl for detail: %s" );

define( '_MD_XOONIPS_ITEM_CHANGE_LOG_AUTOFILL_TEXT', '%s を変更' );
define( '_MD_XOONIPS_ITEM_CHANGE_LOG_AUTOFILL_DELIMITER', ', ' );

//define( '_MD_XOONIPS_ITEM_ASCEND', '&darr;' );
//define( '_MD_XOONIPS_ITEM_DESCEND', '&uarr;' );
define( '_MD_XOONIPS_ITEM_ASCEND', '▼' );
define( '_MD_XOONIPS_ITEM_DESCEND', '▲' );

define( '_MD_XOONIPS_ITEM_RELATED_TO_ADD_ID', '追加する関連アイテムのIDを1行につきひとつ入力してください．' );

define( '_MD_XOONIPS_ITEM_RELATED_TO_EDIT_ID', '削除したい関連アイテムのチェックをOFFにしてください．' );
define( '_MD_XOONIPS_ITEM_RELATED_TO_LEAVE_IT', '関連を残す' );
define( '_MD_XOONIPS_ITEM_RELATED_TO_ITEM_ID', 'アイテムID' );
define( '_MD_XOONIPS_ITEM_RELATED_TO_ITEM_SUMMARY', 'アイテムの概要' );
define( "_MD_XOONIPS_ITEM_RELATED_TO_LABEL", "関連アイテム" );
define( "_MD_XOONIPS_ITEM_RELATED_TO_ADD_ID_BUTTON_LABEL", "アイテムを探す(新しいウィンドウ)" );
define( "_MD_XOONIPS_ITEM_RELATED_TO_DESCRIPTION", "" );
define( "_MD_XOONIPS_ITEM_RELATED_TO_CLOSE_LABEL", "ウィンドウを閉じる" );

define( '_MD_XOONIPS_RIGHTS_SOME_RIGHTS_RESERVED', 'Some rights reserved' );
define( '_MD_XOONIPS_RIGHTS_ALL_RIGHTS_RESERVED', 'All rights reserved' );
define( '_MD_XOONIPS_RIGHTS_ALLOW_COMMERCIAL_USE', 'あなたの作品の営利目的利用を許しますか?' );
define( '_MD_XOONIPS_RIGHTS_ALLOW_MODIFICATIONS', 'あなたの作品の翻案・改変を許しますか?' );
define( '_MD_XOONIPS_RIGHTS_YES_SA', 'はい。ただし、他の人々が同じ条件で共有する場合のみ。' );

/// following defines for moderator 

define('_MD_XNP_BAD_CONFIG','XooNIpsの設定が異常です。xoops_xnp_configテーブルにAL_PATHの指定がありません。');

define("_MD_XOONIPS_MODERATOR_SHULD_BE_MODERATOR"    ,"このエリアへのアクセス権限がありません．モデレータ権限が必要になります．" );

// editgroups.php?op=
define('_MD_XOONIPS_MODERATOR_GROUP_LIST','グループ一覧');
define('_MD_XOONIPS_MODERATOR_GNAME','グループ名');
define('_MD_XOONIPS_MODERATOR_GDESC','グループ詳細');
define('_MD_XOONIPS_MODERATOR_ADMINISTRATOR','aministrator');
define('_MD_XOONIPS_MODERATOR_OPERATION','操作');
define('_MD_XOONIPS_MODERATOR_EDIT','編集');
define('_MD_XOONIPS_MODERATOR_DELETE','削除');
define('_MD_XOONIPS_MODERATOR_GROUP_ADMIN','グループ管理者');
define('_MD_XOONIPS_MODERATOR_CREATE_GROUP','グループ作成');
define('_MD_XOONIPS_MODERATOR_EDIT_GROUP','グループ編集');
define('_MD_XOONIPS_MODERATOR_REALLY_DELETE' ,'このグループを削除しますか?' );
define('_MD_XOONIPS_MODERATOR_ITEM_STORAGE_LIMIT' ,'登録可能なアイテムの最大ディスク容量[MB]' );
define('_MD_XOONIPS_MODERATOR_ITEM_NUMBER_LIMIT' ,'登録可能なアイテムの最大個数' );
define('_MD_XOONIPS_MODERATOR_INDEX_NUMBER_LIMIT' ,'登録可能なインデックスの最大個数' );

// certify.php
define('_MD_XOONIPS_MODERATOR_CERTIFY_USER','XooNIps ユーザ承認');
define('_MD_XOONIPS_MODERATOR_DETAIL','詳細');
define('_MD_XOONIPS_MODERATOR_CERTIFY','承認');

define("_MD_XOONIPS_MODERATOR_ENTER_GROUP_NAME"    ,"グループ名を入力してください" );
define("_MD_XOONIPS_MODERATOR_ERROR_INSERT_GROUP"    ,"グループの登録に失敗しました" );
define("_MD_XOONIPS_MODERATOR_ERROR_SELECT_GROUP"    ,"グループの取得に失敗しました" );
define("_MD_XOONIPS_MODERATOR_ERROR_DELETE_GROUP"    ,"グループの削除に失敗しました" );

define("_MD_XOONIPS_MODERATOR_NOT_ACTIVATED"    ,"承認されていないためアクセスできません．" );
define("_MD_XOONIPS_MODERATOR_NO_CERTIFY_USERS"    ,"承認待ちのユーザはいません．" );

define("_MI_XOONIPS_MODERATOR_PANKUZU_CERTIFY_USERS", "ユーザ承認" );
define("_MI_XOONIPS_MODERATOR_PANKUZU_EDIT_GROUPS", "グループ編集" );
define("_MI_XOONIPS_MODERATOR_PANKUZU_LIST_GROUPS", "Group List" );
define("_MI_XOONIPS_MODERATOR_PANKUZU_CREATE_NEW_GROUPS", "Create new group" );

define("_MD_XOONIPS_MODERATOR_MODIFY_ANY_ITEMS_TITLE", "モデレータは全ユーザのアイテムを編集できる" );

define("_MD_XOONIPS_GROUPNAME_ALREADY_EXISTS", "そのグループ名は既に存在します．" );
define("_MD_XOONIPS_USER_CERTIFICATION_SUCCEED", "ユーザを承認しました．" );

/// following defines for index

define( "_MD_XOONIPS_INDEX_NUMBER_OF_PRIVATE_INDEX_LABEL", "プライベートインデックス数" );
define( "_MD_XOONIPS_INDEX_NUMBER_OF_GROUP_INDEX_LABEL", "グループインデックス数" );
define( "_MD_XOONIPS_INDEX_TOO_MANY_INDEXES", "登録可能なインデックス数を超えたため、インデックスを作成できません" );
define( "_MD_XOONIPS_INDEX_NO_INDEX", "サブインデックスキーワードはありません" );

define( "_MD_XOONIPS_INDEX_BUTTON_REGISTER", "登録");// 
define( "_MD_XOONIPS_INDEX_TITLE_EDIT", "インデックスキーワード編集");// 
define( "_MD_XOONIPS_INDEX_TITLE_ADD", "追加");// 
define( "_MD_XOONIPS_INDEX_TITLE_NEW_INDEX_KEYWORD", "New Index Keyword");// 
define( "_MD_XOONIPS_INDEX_TITLE_MODIFY", "編集");// 
define( "_MD_XOONIPS_INDEX_INDEX_KEYWORD", "インデックスキーワード");// 
define( "_MD_XOONIPS_INDEX_RENAME_TO", "Rename to");// 
define( "_MD_XOONIPS_INDEX_LABEL_UPDOWN", "上へ/下へ");// 
define( "_MD_XOONIPS_INDEX_LABEL_UP", "上へ");// 
define( "_MD_XOONIPS_INDEX_LABEL_DOWN", "下へ");// 
define( "_MD_XOONIPS_INDEX_BUTTON_RENAME", "改名");// 
define( "_MD_XOONIPS_INDEX_BUTTON_DELETE", "削除");// 
define( "_MD_XOONIPS_INDEX_BUTTON_MOVETO", "次へ移動 : ");// 
define( "_MD_XOONIPS_INDEX_LABEL_WITH_SELECTED", "With selected:");// 

define( "_MI_XOONIPS_INDEX_PANKUZU_EDIT_PUBLIC_INDEX_KEYWORD", "公開ツリー編集");// 
define( "_MI_XOONIPS_INDEX_PANKUZU_EDIT_GROUP_INDEX_KEYWORD", "グループツリー編集");// 
define( "_MI_XOONIPS_INDEX_PANKUZU_EDIT_PRIVATE_INDEX_KEYWORD", "プライベートツリー編集");// 
define( "_MD_XOONIPS_INDEX_NAME_CANNOT_BE_EMPTY", "インデックスキーワードが空欄です");//
define( "_MD_XOONIPS_INDEX_DESTINATION_HAS_TOO_MANY_INDEXES", "エラー: 宛先のインデックスはインデックス数が多すぎます");//

define( "_MD_XOONIPS_INDEX_RENAME_MESSAGE", "インデックスキーワードの名前が %s から %s に変更されました．これに伴い次のアイテムにも影響がありました :");//
define( "_MD_XOONIPS_INDEX_RENAME_MAIL_SUBJECT", "インデックスキーワードの名前が変更されました．" );
define( "_MD_XOONIPS_INDEX_DELETE_MESSAGE", "インデックスキーワード %s が削除されました．これに伴い次のアイテムにも影響がありました :");//
define( "_MD_XOONIPS_INDEX_DELETE_MAIL_SUBJECT", "インデックスキーワードが削除されました" );
define( "_MD_XOONIPS_INDEX_MOVETO_MESSAGE", "インデックスキーワード %s が %s へ移動されました．これに伴い次のアイテムも影響がありました :");//
define( "_MD_XOONIPS_INDEX_MOVETO_MAIL_SUBJECT", "インデックスキーワードは移動されました．" );
define( "_MD_XOONIPS_INDEX_TITLE_CONFLICT", "インデックス名 '%s' が競合しています．" );
define( "_MD_XOONIPS_INDEX_TITLE_EXCEEDS", "インデックス名が長すぎます" );
define( "_MD_XOONIPS_INDEX_TITLE_EMPTY", "インデックス名を空にすることはできません．" );
define( "_MD_XOONIPS_INDEX_FORBIDDEN", "未登録ユーザなのでインデックスツリーを表示できません" );

// following defines for configuration

define("_MD_XOONIPS_CONFIG_CONFIG", "XooNIps 基本設定");// 

define("_MD_XOONIPS_CONFIG_CONFIG_TEST_LABEL", "設定テスト");// 
define("_MD_XOONIPS_CONFIG_RESULT_LABEL", "テスト結果");// 
define("_MD_XOONIPS_CONFIG_TEST_AGAIN_LABEL", "再テスト");// 

define("_MD_XOONIPS_CONFIG_SUCCEEDED", "成功");//
define("_MD_XOONIPS_CONFIG_FAILED",    "失敗");//

define("_MD_XOONIPS_CONFIG_ENABLED",   "有効");//
define("_MD_XOONIPS_CONFIG_DISABLED",  "無効");//

define("_MD_XOONIPS_CONFIG_SKIPED",    "スキップ");//

define("_MD_XOONIPS_CONFIG_TEST_L1", "ODBC DSN : ");//
define("_MD_XOONIPS_CONFIG_TEST_L1_NG", "(設定されていません)");//
define("_MD_XOONIPS_CONFIG_TEST_L2", "dl() - 動的モジュール読み込み : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L3", "PHP Unified ODBC 関数 : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L4", "odbc_connect() による Abstract Layer 接続テスト : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L5", "PHP XooNIps Abstract Layer 関数 : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L6", "Abstract Layer の初期化 : ");// 
define("_MD_XOONIPS_CONFIG_TEST_L7", "総合テスト結果 : ");// 

define("_MD_XOONIPS_INDEX_TF_WIDTH", "インデックスツリーブロックの幅");
define("_MD_XOONIPS_INDEX_TF_HEIGHT", "インデックスツリーブロックの高さ");
define("_MD_XOONIPS_PRINT_HEADER", "印刷ページのへッダ");


/// following defines for binder

define( '_MD_XOONIPS_BINDER_ITEMS_TO_REGISTER_TITLE', 'アイテムを登録します' );
define( '_MI_XOONIPS_BINDER_DELETE_CHECKED_ITEM_BUTTON_LABEL', 'チェックされたアイテムを削除します' );
define( '_MD_XOONIPS_BINDER_REGISTERED_ITEMS_TITLE', '登録済みアイテム' );
define( '_MI_XOONIPS_BINDER_ADD_FROM_ITEM_LIST_BUTTON_LABEL', 'アイテム一覧' );
define( '_MI_XOONIPS_BINDER_ADD_FROM_COLUMN_LABEL', "次からアイテムを追加 : " );
define( '_MI_XOONIPS_BINDER_ADD_FROM_INDEX_BUTTON_LABEL', "インデックスキーワード" );
define( '_MI_XOONIPS_BINDER_ADD_FROM_SEARCH_BUTTON_LABEL', "検索" );

define( '_MD_XOONIPS_BINDER_ITEM_REQUIRED', '少なくとも1つ以上のアイテムが必要です' );
define( '_MD_XOONIPS_BINDER_ITEM_LABEL', "アイテム" );

/// following defines for account

//module title for display
define("_MD_XNPACCOUNT", "XooNIps ユーザ管理");

// admin/index.php
define("_MD_XOONIPS_ACCOUNT_ADMIN", "XooNIps ユーザ管理");
define("_MD_XOONIPS_ACCOUNT_ADMIN_USERS", "ユーザ管理");

// error labels
define('_MD_XOONIPS_ACCOUNT_BAD_CONFIG','XooNIps の設定が異常です．xoops_xnp_config テーブルに AL_PATH の指定がありません．');
define('_MD_XOONIPS_ACCOUNT_CANNOT_INITIALIZE_AL','Abstract Layer の初期化に失敗しました．');
define('_MD_XOONIPS_ACCOUNT_DSN_EMPTY','xoonips の dsn が設定されていません．');

//labels of register/edit account items
define("_MD_XOONIPS_ACCOUNT_ADDRESS", "住所" );
define("_MD_XOONIPS_ACCOUNT_DIVISION", "所属" );
define("_MD_XOONIPS_ACCOUNT_TEL", "電話番号" );
define("_MD_XOONIPS_ACCOUNT_FAX", "FAX番号" );
define("_MD_XOONIPS_ACCOUNT_COMPANY_NAME", "機関名/大学名/会社名" );
define("_MD_XOONIPS_ACCOUNT_COUNTRY", "国名" );
define("_MD_XOONIPS_ACCOUNT_ZIPCODE", "郵便番号" );
define("_MD_XOONIPS_ACCOUNT_NOTICE_MAIL", "新着メール送信間隔 [日]" );
define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_NUMBER_LIMIT",  "プライベートアイテムの最大登録数" );
define("_MD_XOONIPS_ACCOUNT_PRIVATE_INDEX_NUMBER_LIMIT", "プライベートインデックスの最大登録数" );
define("_MD_XOONIPS_ACCOUNT_PRIVATE_ITEM_STORAGE_LIMIT", "プライベートアイテムの最大ディスク容量 [MB]" );
define("_MD_XOONIPS_ACCOUNT_POSITION", "職名" );
define("_MD_XOONIPS_ACCOUNT_NSRA", "職名は設定されていません" );
define("_MD_XOONIPS_ACCOUNT_NSRID", "職名の設定がありません" );
define("_MD_XOONIPS_ACCOUNT_APPEAL", "自由記述" );
define("_MD_XOONIPS_ACCOUNT_CVITAE", "略歴" );

define("_MD_XOONIPS_ACCOUNT_XNP_USER_INFO", "ユーザ情報" );

define("_MD_XOONIPS_ACCOUNT_NOTICE_MAIL_TOO_LITTLE", "メール送信間隔には 0以上の数値を指定してください．" );
define("_MD_XOONIPS_ACCOUNT_INVALID_SECRETKEY", "不正なシークレットキーです．" );
define("_MD_XOONIPS_ACCOUNT_PUSH_BUTTON_TO_ENTER_USERINFO", "ボタンを押してください．ユーザ登録画面へ進みます．");
define("_MD_XOONIPS_ACCOUNT_INVITATION_SUCCED", "ご紹介ありがとうございました．" );
define("_MD_XOONIPS_ACCOUNT_NOTREGISTERED1", "今すぐ<a href='registeruser.php'>登録</a>しませんか？" );
define("_MD_XOONIPS_ACCOUNT_NOTREGISTERED2", "" );

// register.php errormessage
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ADDRESS"     ,"住所"                           . "が長すぎます．全角127文字以下にして下さい．");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_DIVISION"    ,"所属"                          . "が長すぎます．全角127文字以下にして下さい．");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_TEL"         ,"電話番号"                          . "が長すぎます．半角32文字以下にして下さい．");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_COMPANY_NAME","FAX番号"                            . "が長すぎます．半角32文字以下にして下さい．");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_ZIPCODE"     ,"郵便番号"                          . "が長すぎます．全角127文字以下にして下さい．");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_COUNTRY"     ,"機関名/大学名/会社名" . "が長すぎます．全角127文字以下にして下さい．");
define("_MD_XOONIPS_ACCOUNT_REG_TOO_LONG_FAX"         ,"国名"                           . "が長すぎます．半角32文字以下にしてください．");
define("_MD_XOONIPS_ACCOUNT_MUST_BE_FILLED_IN", "'%s' を入力してください．" );

define("_MD_XOONIPS_ACCOUNT_INVITE_USER"    ,"ユーザ紹介" );
define("_MD_XOONIPS_ACCOUNT_INVITE_USER_MAIL_SUBJECT"    ,"ご紹介のお知らせ " );

// useradmin.php
define("_MD_XOONIPS_ACCOUNT_CANNOT_ACQUIRE_USER_INFO", "ユーザ情報の取得に失敗しました．" );
define("_MD_XOONIPS_ACCOUNT_CANNOT_UPDATE_USER_INFO" , "ユーザ情報の更新に失敗しました．" );

// groupadmin.php
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN"                 ,"グループ管理");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_GROUP_LIST"      ,"管理グループ一覧");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_MEMBERS"         ,"メンバー");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_NON_MEMBERS"     ,"非メンバー");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_ADD_BUTTON"      ,"追加 -->");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_DELETE_BUTTON"   ,"<-- 削除");
define("_MD_XOONIPS_ACCOUNT_GROUPADMIN_NO_EDITABLE_GROUPS"        ,"管理可能なグループはありません．");

define("_MD_XOONIPS_ACCOUNT_QUERY_ERROR"    ,"データベースのクエリエラーです．" );

define("_MD_XOONIPS_ACCOUNT_FORBIDDEN"    ,"このエリアへのアクセスは許可されていません．" );

define( "_MD_XOONIPS_ACCOUNT_SELECT_USER", "ユーザ選択" );
define( "_MD_XOONIPS_ACCOUNT_DELETE_USER", "ユーザ削除" );
define( "_MD_XOONIPS_ACCOUNT_PASSWORD_DOESNT_MATCH", "パスワードが一致しません．" );

define( "_MD_XOONIPS_ACCOUNT_PREFERENCE", "一般設定" );

// 
// mesasge for user registration
// 
define("_MD_XOONIPS_ACTIVATE_KEY_SUBJECT", '%sさんのアクティベートキーです' );
define("_MD_XOONIPS_ACTIVATE_BY_USER_CERTIFY_MANUAL", '登録メールアドレス宛にアクティベートキーを送信しました。メールの指示にしたがってアカウントをアクティベートしてください。アクティベートした後は、モデレータによる承認をお待ちください。' );
define("_MD_XOONIPS_ACTIVATE_BY_USER_CERTIFY_AUTO", '登録メールアドレス宛にアクティベートキーを送信しました。メールの指示にしたがってアカウントをアクティベートしてください。' );
define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_MANUAL", 'モデレータへアカウントの承認を申請しました。モデレータの承認をお待ちください。承認完了時にはメールにてお知らせします。' );
define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_MANUAL_MAILNG", 'アカウントの承認を申請するメールをモデレータへ送信できませんでした。管理者およびモデレータに問い合わせてください。');
define("_MD_XOONIPS_ACTIVATE_AUTO_CERTIFY_AUTO", 'アカウントの承認が完了しました。登録時に入力したユーザ名とパスワードでログインしてください。');
define("_MD_XOONIPS_ACTIVATE_BY_ADMIN_CERTIFY_AUTO", '登録が完了しました。サイト管理者のアクティベートをお待ちください。アクティベート完了時にはメールにてお知らせします。');
define("_MD_XOONIPS_ACTIVATE_BY_ADMIN_CERTIFY_MANUAL", '登録が完了しました。サイト管理者のアクティベートと、モデレータの承認をお待ちください。承認完了時にはメールにてお知らせします。');
define("_MD_XOONIPS_ACTIVATE_BY_ADMIN_MAILNG", 'サイト管理者にアクティベートの要求メールを送信できませんでした。サイト管理者に問い合わせてください。' );

define("_MD_XOONIPS_ACTIVATED_BY_USER_CERTIFIED_AUTO", 'アカウントを承認しました。登録時のユーザ名とパスワードでログインしてください。');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_CERTIFIED_AUTO", 'アカウントをアクティベートしました。登録時のメールアドレスに通知メールを送信しました。');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_CERTIFIED_AUTO_MAILNG", 'アカウントをアクティベートしましたが、登録時のメールアドレスに通知メールを送信できませんでした。');
define("_MD_XOONIPS_ACTIVATED_BY_USER_AND_CERTIFY_MANUAL", 'アカウントをアクティベートしました。アカウントがモデレータに承認されるまでお待ちください。');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_AND_CERTIFY_MANUAL", 'アカウントをアクティベートしました。モデレータがアカウント承認した後、登録メールアドレスに通知されます。');
define("_MD_XOONIPS_ACTIVATED_BY_USER_AND_CERTIFY_MANUAL_MAILNG", 'アカウントの承認を申請するメールをモデレータへ送信できませんでした。管理者およびモデレータに問い合わせてください。');
define("_MD_XOONIPS_ACTIVATED_BY_ADMIN_AND_CERTIFY_MANUAL_MAILNG", 'アカウントの承認を申請するメールをモデレータへ送信できませんでした。');

define("_MD_XOONIPS_ACCOUNT_NOT_ACTIVATED", 'モデレータの承認が完了していないため、XooNIpsを利用できません。モデレータの承認をお待ちください。承認完了時にはメールにてお知らせします。' );
define("_MD_XOONIPS_USER_ACTIVATED", 'アカウントはアクティベートされました。モデレータによる承認をお待ちください。');
define("_MD_XOONIPS_USER_NOACTTPADM", 'アカウントのアクティベート、またはモデレータの承認が完了していないため、XooNIpsを利用できません。');
define("_MD_XOONIPS_ACCOUNT_ALREADY_CERTIFIED", "既に承認されています" );
define("_MD_XOONIPS_ACCOUNT_ACTIVATE_NG", "アカウントをアクティベートできませんでした。管理者およびモデレータに問い合わせてください。" );

//subjects for e-mail of user registration
define("_MD_XOONIPS_ACCOUNT_CERTIFIED", 'アカウントの承認が完了しました。' );
define('_MD_XOONIPS_ACCOUNT_REGISTERD','ユーザを承認してください');


// admin/config.php
define("_MD_XOONIPS_ACCOUNT_CONFIG", "サイト動作設定");
define("_MD_XOONIPS_ACCOUNT_MODERATOR_GROUP_TITLE", "モデレータグループ");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_TITLE", "アカウント承認");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_DESC", "");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_AUTO", "自動");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_USER_ON", "手動(要審査)");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_TITLE", "アイテム承認");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_DESC", "");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_AUTO", "自動");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_ON", "手動(要審査)");
define("_MD_XOONIPS_ACCOUNT_CERTIFY_ITEM_OFF", "公開禁止");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_TITLE", "公開アイテムの閲覧ポリシー");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_DESC", "");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_PLATFORM", "XooNIps 登録ユーザのみ");
define("_MD_XOONIPS_ACCOUNT_PUBLIC_ITEM_ALL", "全て(ゲストユーザを含む)");
define("_MD_XOONIPS_ACCOUNT_UPLOAD_DIR_TITLE", "アップロードファイル格納ディレクトリ");
define("_MD_XOONIPS_ACCOUNT_REALNAME_OPTIONAL_TITLE" , '本名'  . 'の入力' );
define("_MD_XOONIPS_ACCOUNT_ADDRESS_OPTIONAL_TITLE" , '住所'  . 'の入力' );
define("_MD_XOONIPS_ACCOUNT_DIVISION_OPTIONAL_TITLE", '所属' . 'の入力' );
define("_MD_XOONIPS_ACCOUNT_TEL_OPTIONAL_TITLE"     , '電場番号'      . 'の入力' );
define("_MD_XOONIPS_ACCOUNT_COMPANY_OPTIONAL_TITLE" , '会社名'  . 'の入力' );
define("_MD_XOONIPS_ACCOUNT_COUNTRY_OPTIONAL_TITLE" , '国名'  . 'の入力' );
define("_MD_XOONIPS_ACCOUNT_ZIPCODE_OPTIONAL_TITLE" , '郵便番号'  . 'の入力' );
define("_MD_XOONIPS_ACCOUNT_FAX_OPTIONAL_TITLE"     , 'FAX番号'      . 'の入力' );

define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_NUMBER_LIMIT_TITLE"  , '個人領域に登録可能なアイテム数の最大値' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_INDEX_NUMBER_LIMIT_TITLE" , '個人領域に登録可能なインデックス数の最大値' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_PRIVATE_ITEM_STORAGE_LIMIT_TITLE" , '個人領域の利用可能なディスク容量の最大値 [MB]' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_NUMBER_LIMIT_TITLE"    , 'グループ領域に登録可能なアイテム数の最大値' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_INDEX_NUMBER_LIMIT_TITLE"   , 'グループ領域に登録可能なインデックス数の最大値' );
define("_MD_XOONIPS_ACCOUNT_DEFAULT_GROUP_ITEM_STORAGE_LIMIT_TITLE"   , 'グループ領域の利用可能なディスク容量の最大値 [MB]' );

define("_MD_XOONIPS_ACCOUNT_AMAZON_ASSOCIATES_ID_TITLE"   , 'AmazonアソシエイトID' );

define("_MD_XOONIPS_ACCOUNT_OPTIONAL"     , '任意'     );
define("_MD_XOONIPS_ACCOUNT_REQUIRED"     , '必須'     );

define( "_MD_XOONIPS_ACCOUNT_REQUIRED_MARK", "(*)" );
define( "_MD_XOONIPS_ACCOUNT_EXPLAIN_REQUIRED_MARK", "(*) = 必須" );

define( '_MI_XOONIPS_EVENT_LOG_EVENT_TYPES','dummy,Login Failure,Login Success,Logout,Insert Item,Update Item,Delete Item,View Item,Download File,Request To Certify Item,Insert Index,Update Index,Delete Index,Certify Item,Reject Item,Request To Insert Account,Certify Account,Insert Group,Update Group,Delete Group,Insert Group Member,Delete Group Member,View Top Page,Quick Search,Advanced Search,Start SU,End SU' );
define( '_MI_XOONIPS_EVENT_LOG_EVENT_COLUMNS','Event Type,Timestamp,Exec UID,Remote Host,Index ID,Item ID,File ID,UID,GID,Search Keyword,Login Name,Additional Information' );
define( "_MD_XOONIPS_EVENT_LOG_00", "" );
define( "_MD_XOONIPS_EVENT_LOG_10", "" );
define( "_MD_XOONIPS_EVENT_LOG_11", "年" );
define( "_MD_XOONIPS_EVENT_LOG_12", "月" );
define( "_MD_XOONIPS_EVENT_LOG_13", "日 から " );
define( "_MD_XOONIPS_EVENT_LOG_20", "" );
define( "_MD_XOONIPS_EVENT_LOG_21", "年" );
define( "_MD_XOONIPS_EVENT_LOG_22", "月" );
define( "_MD_XOONIPS_EVENT_LOG_23", "日" );
define( "_MD_XOONIPS_EVENT_LOG_30", "のイベントログを" );
define( "_MD_XOONIPS_EVENT_LOG_DOWNLOAD", "Download" );

//pankuzu
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_PLATFORM_USER', 'XooNIps ユーザ管理' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_GROUP_ADMINISTRATOR', 'グループ管理' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_MODERATOR', 'モデレータ' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_SEPARATOR', '&nbsp;&raquo;&raquo;&nbsp;' );
define( '_MI_XOONIPS_ACCOUNT_PANKUZU_EDIT_GROUPS', 'グループ編集' );
define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_PUBLIC_ITEMS', '公開アイテム承認' );
define( '_MI_XOONIPS_ITEM_PANKUZU_CERTIFY_GROUP_ITEMS', 'グループ公開アイテム承認' );
define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_ACCOUNT', 'プロフィールの編集' );
define( '_MI_XOONIPS_ITEM_PANKUZU_VIEW_ACCOUNT', 'アカウント情報' );
define( "_MI_XOONIPS_EVENT_LOG_PANKUZU", "イベントログ" );
define( '_MI_XOONIPS_ITEM_PANKUZU_EDIT_CURRICULUM_VITAE', '略歴の編集' );

//export/import
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT', 'エクスポート' );
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_CONFIG', 'エクスポート設定' );
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_LICENSE', '利用規約(ライセンス)' );
define( '_MD_XOONIPS_EXPORT_PANKUZU_EXPORT_INDEX', 'インデックスをエクスポート' );
define( '_MD_XOONIPS_EXPORT_CONFIG_TITLE', 'エクスポート設定' );
define( '_MD_XOONIPS_EXPORT_CONFIG_SUBMIT', '次へ' );
define( '_MD_XOONIPS_EXPORT_RECURSIVE', 'インデックスを再帰的にエクスポートする' );
define( '_MD_XOONIPS_EXPORT_ENABLED', 'Exportを許可' );
define( '_MD_XOONIPS_EXPORT_ATTACHMENT', '添付ファイルをエクスポートする' );
define( '_MD_XOONIPS_PRIVATE_IMPORT_ENABLED', 'Importを許可(XooNIpsユーザ)' );
define( '_MD_XOONIPS_EXPORT_BUTTON_LABEL', 'エクスポート' );
define( '_MD_XOONIPS_EXPORT_EXPORT_LICENSE', '利用規約(ライセンス)' );
define( '_MD_XOONIPS_EXPORT_LICENSE', 'ライセンス' );
define( '_MD_XOONIPS_EXPORT_ACCEPT', '合意する' );
define( '_MD_XOONIPS_EXPORT_CANNOT_BE_EXPORTED_ITEMS', '以下のアイテムはエクスポートできません' );
define( '_MD_XOONIPS_EXPORT_NO_ITEMS_FOUND', '該当するアイテムはありません．' );
define( '_MD_XOONIPS_EXPORT_ACCEPT_ALL', 'すべてのライセンスに合意する' );
define( '_MD_XOONIPS_EXPORT_EXPORT_ITEMS_EMPTY', 'Exportするアイテムが選択されていません．' );
define( '_MD_XOONIPS_EXPORT_LICENSE_AGREEMENT_SUBMIT', 'ダウンロード' );
define( '_MD_XOONIPS_EXPORT_EXPORT_INDEX', '以下の設定でインデックスをエクスポートします' );
define( '_MD_XOONIPS_EXPORT_TYPE_ITEM', 'アイテムをエクスポートする' );
define( '_MD_XOONIPS_EXPORT_TYPE_INDEX', 'インデックスツリーをエクスポートする' );
define( '_MD_XOONIPS_IMPORT_TITLE', 'インポート' );
define( '_MD_XOONIPS_IMPORT_FILE', 'Importするファイル' );
define( '_MD_XOONIPS_IMPORT_INDEX', 'Import先インデックス' );
define( '_MD_XOONIPS_IMPORT_INDEX_TEXT', 'Importしたいインデックスをインデックスツリーから選択してください' );
define( '_MD_XOONIPS_IMPORT_REQUIRED', '(必須)' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_IMPORT', 'インポート' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_RESOLVE_CONFLICT', '衝突の解決' );
define( '_MD_XOONIPS_IMPORT_TITLE_RESOLVE_CONFLICT', '衝突の解決' );
define( '_MD_XOONIPS_IMPORT_IMPORT_ALL', '全てインポート' );
define( '_MD_XOONIPS_IMPORT_IMPORT_ITEM', 'インポートするアイテム' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_UPLOAD_FILE', 'ファイルアップロード' );
define( '_MD_XOONIPS_IMPORT_IMPORT_SUCCESSFULLY', 'インポートを完了しました．' );
define( '_MD_XOONIPS_IMPORT_NO_ITEMS_IMPORTED', 'インポートするアイテムがありません．' );
define( '_MD_XOONIPS_IMPORT_INDEX_NUMBER_LIMIT_OVER_FLOW', 'これ以上インデックスをインポートできません．サイト管理者に連絡して下さい．' );
define( '_MD_XOONIPS_IMPORT_ITEM_NUMBER_LIMIT_OVER_FLOW', 'これ以上アイテムをインポートできません．サイト管理者に連絡して下さい．' );
define( '_MD_XOONIPS_IMPORT_RESOLVE_CONFLICT_SUBMIT', '次へ' );
define( '_MD_XOONIPS_IMPORT_UPLOAD_SUBMIT', '次へ' );
define( '_MD_XOONIPS_IMPORT_PANKUZU_CHECK_LENGTH', '文字数超過のチェック' );
define( '_MD_XOONIPS_IMPORT_TITLE_CHECK_LENGTH', '文字数超過のチェック' );
define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_SUBMIT', 'アップロード' );
define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_WARNING', '以下のアイテムは、文字数超過のため一部切り捨てられます(赤字の部分)．' );
define( '_MD_XOONIPS_IMPORT_CHECK_LENGTH_NO_WARNING', '文字数が超過するアイテムはありません．' );
define( '_MD_XOONIPS_IMPORT_INDEX_CANNOT_WRITE', '以下のインデックスは無視されます．インポートできるインデックスはあなたのプライベートインデックスのみです．' );
define( '_MD_XOONIPS_IMPORT_IGNORE_CHECK', '衝突と文字数超過をチェックしない' );
define( '_MD_XOONIPS_IMPORT_NO_STRINGS_ARE_TRIMMED', '文字数制限を越える文字列はありませんでした．' );
define( '_MD_XOONIPS_IMPORT_NO_CONFLICT_ITEMS', '衝突するアイテムはありませんでした．' );
define( '_MD_XOONIPS_IMPORT_NUMBER_OF_CONFLICT_ITEMS', '衝突するアイテムの数：' );
define( '_MD_XOONIPS_IMPORT_FOLLOWING_ITEM_CONFLICT', '以下のアイテムが重複しています' );
define( '_MD_XOONIPS_IMPORT_IMPORT_ALL_AS_NEW', "衝突する全てのアイテムを新しいアイテムとしてインポートする\n（上書きチェックボックスの指定を無視します）．" );
define( '_MD_XOONIPS_IMPORT_IMPORT_MODIFY', 'インポート先インデックスにある以下の衝突アイテムを上書きする' );
define( '_MD_XOONIPS_IMPORT_CONFLICT_ITEMS_IN_OTHER_INDEXES', '別のインデックスに以下の衝突アイテムがあります(上書きしません)' );
define( '_MD_XOONIPS_CONFLICT_ITEMS_IN_THE_SAME_FILE', 'インポートファイル内に以下の衝突アイテムがあります' );
define( '_MD_XOONIPS_IMPORT_IMPORT_CAN_NOT_MODIFY', '複数のアイテムと衝突するのでインポートできません' );
define( '_MD_XOONIPS_IMPORT_LOGGING', 'ログを出力する' );
define( '_MD_XOONIPS_IMPORT_ERROR', 'インポート処理中にエラーが発生しました．' );
define( '_MD_XOONIPS_IMPORT_READY', 'インポートできます．' );
define( '_MD_XOONIPS_IMPORT_NO_ERROR', 'エラーはありません．' );
define( '_MD_XOONIPS_IMPORT_REVIEW_LOG', 'ログを確認してください．' );
define( '_MD_XOONIPS_IMPORT_LOCAL_FILE', 'ローカルファイルをインポートする' );
define( '_MD_XOONIPS_IMPORT_REMOTE_FILE', 'サーバ上のファイルをインポートする' );
define( '_MD_XOONIPS_IMPORT_ERROR_CHECK_ONLY', 'エラーチェックだけを行う' );
define( '_MD_XOONIPS_IMPORT_CONTRIBUTOR_SELECT', '指定ユーザの権限でインポートする' );
define( '_MD_XOONIPS_IMPORT_ERROR_CKECK_DONE', 'エラーチェックを完了しました．' );
define( '_MD_XOONIPS_IMPORT_INDEX_TREE_CREATED', '以下のインデックスツリーをインポートしました（リスト中の既存の同名インデックスの内容は変更されていません）．' );
define( '_MD_XOONIPS_IMPORT_INDEX_TREE_FAILED', 'インデックスツリーのインポートに失敗しました' );
define( '_MD_XOONIPS_IMPORT_FILE_NOT_FOUND', 'インポートファイルが見つかりません．' );
define( '_MD_XOONIPS_IMPORT_FILE_NOT_SPECIFIED', 'インポートファイルが指定されていません．' );
define( '_MD_XOONIPS_IMPORT_CERTIFY_AUTO', '公開インデックスに登録するアイテムを自動承認する' );
define( '_MD_XOONIPS_IMPORT_NO_ITEMS_ARE_FOUND', 'インポートするアイテムが見つかりませんでした．インポートファイルの内容を確認してください．' );
define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX', '以下のインデックスをインポートします．' );
define( '_MD_XOONIPS_IMPORT_FOLLOWING_INDEX_TEST', '以下のインデックスをインポートできます．' );
define( '_MD_XOONIPS_IMPORT_CIRCULAR_INDEX', 'インデックスが循環構造を持っているため、インポートできません．' );

define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE', 'RSSのファイルパス' );
define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE_NOT_WRITABLE_ERROR', '書き込みできません．'._MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE.'を確認してください' );
define( '_MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE_PARENT_DIR_ERROR', '親ディレクトリへのアクセスは禁止されています．'._MD_XOONIPS_ACCOUNT_RSS_FILE_PATH_TITLE.'を確認してください' );
define( '_MD_XOONIPS_ACCOUNT_DEFAULT_RSS_ITEM_MAX_TITLE', 'RSSに含める最大アイテム数(0以上)' );

define( '_MD_XOONIPS_EVENT_ITEM_IS_SHOWN_IN', 'アイテムが以下のインデックスに公開されました' );
define( '_MD_XOONIPS_EVENT_NEW_GROUP', '新しいグループが作成されました' );

define( '_MD_XOONIPS_ITEM_LANG_LABEL', '言語' );
define( '_MD_XOONIPS_ITEM_LANG_OPTION_IDS', 'eng,jpn,fra,deu,esl,ita,dut,sve,nor,dan,fin,por,chi,kor' );
define( '_MD_XOONIPS_ITEM_LANG_OPTION_NAMES', '英語,日本語,フランス語,ドイツ語,スペイン語,イタリア語,オランダ語,スウェーデン語,ノルウェー語,デンマーク語,フィンランド語,ポルトガル語,中国語,韓国語' );


define( '_MD_XOONIPS_DOWNLOAD_LIMITATION_OPTION_LABEL', 'ダウンロード制限' );
define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION', 'ダウンロードファイルオプション' );
define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_YES', 'メタデータとZIP（推奨）' );
define( '_MD_XOONIPS_DOWNLOAD_FILE_COMPRESSION_NO' , '圧縮なし' );
define( '_MD_XOONIPS_DOWNLOAD_ABNORMAL_CONFIGURATION' , 'ダウンロードファイルオプション設定の異常' );

define( '_MD_XOONIPS_ITEM_ATTACHMENT_DL_LIMIT_LOGINUSER_LABEL', 'ログインユーザ' );
define( '_MD_XOONIPS_ITEM_ATTACHMENT_DL_LIMIT_EVERYONE_LABEL', '全てのユーザ' );
define( '_MD_XOONIPS_ITEM_ATTACHMENT_DL_LIMIT_LOGINUSER_ONLY_LABEL', 'ログインユーザのみ' );

define( '_MD_XOONIPS_REPOSITORY_NAME_TITLE', 'リポジトリ名' );
define( '_MD_XOONIPS_REPOSITORY_NIJC_CODE_TITLE', 'データベースID（NIJCコード）' );
define( '_MD_XOONIPS_REPOSITORY_DELETION_TRACK_TITLE', 'アイテムの削除状態を保存する日数' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_TITLE', '&lt;institution&gt;の値' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_META_AUTHOR', 'Meta Author' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_CREATOR', 'アイテム登録者' );
define( '_MD_XOONIPS_REPOSITORY_INSTITUTION_NONE', '使用しない' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_TITLE', '&lt;publisher&gt;の値' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_META_AUTHOR', 'Meta Author' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_CREATOR', 'アイテム登録者' );
define( '_MD_XOONIPS_REPOSITORY_PUBLISHER_NONE', '使用しない' );

//admin/oaipmh.php
define( '_MD_XOONIPS_OAIPMH_CONFIG', 'OAI-PMHの設定' );
define( '_MD_XOONIPS_OAIPMH_CONFIG_REPOSITORIES', 'ハーベストするリポジトリのURL(リポジトリごとに改行)' );
define( '_MD_XOONIPS_OAIPMH_CONFIG_LOGS', '最後にハーベストしたときの結果(この項目は編集できません)' );
define( '_MD_XOONIPS_OAIPMH_HARVESTING', 'ハーベストする' );
define( '_MD_XOONIPS_OAIPMH_HARVESTING_EXPLAIN', 'いますぐハーベストするにはこのボタンを押してください' );
define( '_MD_XOONIPS_OAIPMH_HARVEST_RESULT', 'ハーベスト結果' );
define( '_MD_XOONIPS_BACK_TO_OAIPMH_CONFIGURATION', _MD_XOONIPS_OAIPMH_CONFIG.'に戻る' );

define( '_MD_XOONIPS_METADATA_SEARCH_LABEL', 'メタデータ検索' );

define( '_MD_XOONIPS_FILESEARCH', 'ファイル検索' );
define( '_MD_XOONIPS_FILESEARCH_NAME', 'モジュール名' );
define( '_MD_XOONIPS_FILESEARCH_VERSION', 'バージョン' );
define( '_MD_XOONIPS_FILESEARCH_RESCAN', '全てのファイルを再スキャン' );

// labels for item_show (edit)
define( '_MD_XOONIPS_ITEMSHOW_CURRICULUM_VITAE', '略歴' );
define( '_MD_XOONIPS_ITEM_SHOW_OPTIONAL_TITLE', '公開領域にある全てのアイテムから業績アイテムを選択する<br />（いいえ：ユーザ本人が登録したアイテムから選択可能）' );
define( '_MD_XOONIPS_ITEM_SHOW_EDIT_TITLE', '業績アイテム選択' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_PREV', '前へ' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_NEXT', '次へ' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_CHECK', 'チェック' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_ITEMS', 'アイテム' );
define( '_MD_XOONIPS_ITEM_SHOW_ITEMLIST_SUBMIT', '変更' );
define( '_MD_XOONIPS_NEED_LOGIN', 'ログインすると業績の閲覧ができます' );

// admin/posi_order.php
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_TITLE', '職名表示順設定' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_EXPLAIN', '表示順の値が０未満ならその職名は画面に表示されません' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_POSI_LABEL', '職名' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_ORDER_LABEL', '表示順' );
define( '_MD_XOONIPS_POSIORDER_POSIORDER_SELECT_CHECK_LABEL', '削除チェック' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_TITLE', '職名追加フォーム' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_EXPLAIN', '表示順が空欄なら０を設定します' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_LABEL', '職名追加' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSITITLE_LABEL', '職名' );
define( '_MD_XOONIPS_POSIORDER_ADDPOSI_POSIORDER_LABEL', '表示順' );
define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_TITLE', 'ユーザ表示順設定' );
define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_EXPLAIN', '表示順の値が０未満ならそのユーザは画面に表示されません' );
define( '_MD_XOONIPS_POSIORDER_USERORDER_SELECT_LABEL', '職名 [ ユーザ名 ]' );

// labels of userlists, showusers
define( '_MD_XOONIPS_USERLIST_TITLE', 'ユーザ一覧' );
define( '_MD_XOONIPS_USERLIST_EXPLANATION', 'ユーザ名をクリックすると各ユーザの情報を表示します' );

define( '_MD_XOONIPS_SHOW_USER_TITLE', 'ユーザ情報' );
define( '_MD_XOONIPS_SEND_MESSAGE', 'メッセージ送信' );
define( '_MD_XOONIPS_SHOW_CV_LABEL', '略歴' );
define( '_MD_XOONIPS_SHOW_PUBILICATION_LIST', '業績リスト' );
define( '_MD_XOONIPS_SHOW_BACKTOLIST_LABEL', '戻る' );
define( '_MD_XOONIPS_VIEW_USER_ACCOUNT', 'アカウント確認' );
define( '_MD_XOONIPS_EDIT_LISTS', '編集' );
define( '_MD_XOONIPS_ORDER_CHANGE', '表示順変更' );

define( '_MD_XOONIPS_UPLOAD_MAX_FILESIZE', '最大ファイルサイズ:' );
define( '_MD_XOONIPS_UPLOAD_ERR_OK', 'アップロード成功' );
define( '_MD_XOONIPS_UPLOAD_ERR_INI_SIZE', 'ファイルサイズが大きすぎます( upload_max_filesize )' );
define( '_MD_XOONIPS_UPLOAD_ERR_FORM_SIZE', 'ファイルサイズが大きすぎます( MAX_FILE_SIZE )' );
define( '_MD_XOONIPS_UPLOAD_ERR_PARTIAL', 'ファイルの一部しかアップされませんでした' );
define( '_MD_XOONIPS_UPLOAD_ERR_NO_FILE', 'ファイルはアップロードされませんでした' );
define( '_MD_XOONIPS_UPLOAD_ERR_NO_TMP_DIR', 'テンポラリフォルダが見付かりません' );
define( '_MD_XOONIPS_UPLOAD_ERR_CANT_WRITE', 'ディスクに書き込み出来ませんでした' );

// labels for edit curriculum vitae, publication list
define( '_MD_XOONIPS_EDIT_CV_TITLE', '略歴の編集' );
define( '_MD_XOONIPS_EDIT_CURRICULUM_VITAE', '略歴編集' );
define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_LABEL', '略歴追加' );
define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE_WARNING', '項目を入力してください' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_FROM', 'From' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_TO', 'To' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_TITLE', '項目' );
define( '_MD_XOONIPS_ADD_CURRICULUM_VITAE', '追加' );
define( '_MD_XOONIPS_MODIFY_CURRICULUM_VITAE_LABEL', '略歴編集' );
define( '_MD_XOONIPS_NO_CURRICULUM_VITAE_DATA', '略歴データは登録されていません' );
define( "_MD_XOONIPS_CURRICULUM_VITAE_BUTTON_EDIT", "変更");
define( '_MD_XOONIPS_CURRICULUM_VITAE_CHECK_INFO', 'ユーザ情報へ戻る' );
define( '_MD_XOONIPS_CURRICULUM_VITAE_INSERT', '略歴データを追加します' );
define( '_MD_XOONIPS_NO_PUBLICATION_ITEM_DATA', '業績リストにアイテムが登録されていません．' );
define( '_MD_XOONIPS_PUBLICATION_ITEM_CHANGE', '業績表示順変更' );
define( '_MD_XOONIPS_PUBLICATION_ITEM_INSERT', '業績リストを編集しています' );

define( '_MD_XOONIPS_RANKING_UP', '▲' );
define( '_MD_XOONIPS_RANKING_DOWN', '▼' );
define( '_MD_XOONIPS_RANKING_NUM_ROWS_1', '各ランキングの上位' );
define( '_MD_XOONIPS_RANKING_NUM_ROWS_2', '件を表示します．' );
define( '_MD_XOONIPS_RANKING_DAYS_1', '過去' );
define( '_MD_XOONIPS_RANKING_DAYS_2', '日間のデータのみをランキング対象とします．<br />この指定をONにした場合，集計値ファイルの値はランキングに反映されません．' );

define( '_MD_XOONIPS_RANKING_WHAT_DELETING_LOG_IS', '※ ログを消去するとランキングがクリアされます．<br />それを避けるには，ログ消去の前後で集計値ファイルのダウンロード・アップロードを行ってください．' );
define( '_MD_XOONIPS_RANKING_FILE_CONFIG_EXPLAIN', '集計値のアップロード・ダウンロードを行います' );
define( '_MD_XOONIPS_RANKING_DOWNLOAD_FILE', 'ダウンロード' );
define( '_MD_XOONIPS_RANKING_UPLOAD_FILE', 'アップロード' );
define( '_MD_XOONIPS_RANKING_CLEAR', 'クリアする' );

define( '_MD_XOONIPS_RANKING_LABEL', 'ランキング用ブロック' );
define( '_MD_XOONIPS_RANKING_NEW_LABEL', '新着ランキング用ブロック' );
define( '_MD_XOONIPS_RANKING_CHECK_RANKING_LABEL', '表示するランキングを選択してください(複数チェック可)' );
define( '_MD_XOONIPS_RANKING_LOCKED', '現在集計中です．数秒待ってからリトライしてください．' );

define("_MI_XOONIPS_RANKING_CONFIG", "ランキング設定"); 
define("_MI_XOONIPS_RANKING_FILE_CONFIG", "ランキング集計ファイル設定"); 
define("_MD_XOONIPS_RANKING_VISIBLE", "表示する"); 
define("_MD_XOONIPS_RANKING_NAME", "表示内容"); 

define("_MD_XOONIPS_RANKING_DOWNLOAD_LABEL", "ダウンロードするファイル名"); 
define("_MD_XOONIPS_RANKING_UPLOAD_LABEL", "アップロードするファイル"); 
define("_MD_XOONIPS_RANKING_CLEAR_SOME_LABEL", "%s ～ %s の集計値を持っています"); 
define("_MD_XOONIPS_RANKING_CLEAR_EMPTY_LABEL", "集計値はありません"); 
define("_MD_XOONIPS_RANKING_CLEAR_LABEL", "集計値のクリア"); 

// admin/itemtype_order.php
define("_MD_XOONIPS_ITEMTYPE_CONFIGURATION_LABEL", "アイテムタイプ設定");
define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_LABEL", "アイテムタイプ表示順変更");
define("_MD_XOONIPS_ITEMTYPE_ORDER_SELECT_EXPLAIN", "表示順は1以上の整数を指定してください．");

define("_MD_XOONIPS_SU_TITLE", "suの開始");
define("_MD_XOONIPS_SU_TARGET_USER", "アカウントの切り替え先");
define("_MD_XOONIPS_SU_ADMIN_PASSWORD", "あなたのパスワード");
define("_MD_XOONIPS_SU_OK", "OK");
define("_MD_XOONIPS_SU_CANNOT_LOGOUT", "ログアウトする前にsuを終了してください．");

define("_MD_XOONIPS_SU_START", "アカウントを切り替えています");
define("_MD_XOONIPS_SU_FAIL", "パスワードが異なります");
define("_MD_XOONIPS_SU_END", "管理者に戻ります");
define("_MD_XOONIPS_SU_EXPLAIN", "一時的に他ユーザのアカウントで作業することができます．");

?>
